# compairingnumber
**This package help you to find greater and smaller number between three numbers

# Getting started
## Installing the Package
> py -m pip install --index-url https://pypi.org/simple/ comparingnumber_HarshDhas

## using the package
` from HDPACKAGES import python `

# working of package
**the user needs to give three number inputs as x,y,z . theen gives greatest and smallest number among three numbers.
